@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 import time
 import json
-from article_extract.utils.data_loader import web_from_internet, bytes_to_lxml, extract_article_data
+from utils.data_loader import web_from_internet, bytes_to_lxml, extract_article_data
 
 
 def extractor(url, is_content_html=False):
